import axios from 'axios';
import Webview from '../js/webview.js';

axios.interceptors.request.use(config => {
    config.timeout = 6000;
    return config;
}, err => {
    Webview.toast('请求出错了！');
    return Promise.resolve(err);
})

axios.interceptors.response.use(data => {
    return data
}, err => {
    if(!err.response) {
        Webview.toast('请求超时');
        return Promise.resolve(undefined);
    }

    let errMsg = '请求出错了！';

    // 未登录 => 跳登录
    if(err.response.status === 401) {
        // errMsg = '您还未登录！';
        // // 跳登录/注册来源跟踪
        // let source = {
        //     developer: 'web_0021A47ECC1E4986ACC784524C2C4817',  // 来自开放平台
        //     account: 'web_43A1F5AC737B4BB584A0EB4EBAFEE578'     // 来自账户中心
        // }

        // let href = Rokid.domain.account + '/account.html#/login';
        // let querys = '';

        // let hrefWithoutToken = function () {
        //     let reg = new RegExp("token" + "=([^&]*)(\\s|&|$)", "i")
        //     return encodeURIComponent(location.href.replace(reg, ''))
        // }

        // if(/developer[a-zA-Z-_]*\.rokid\.com/gi.test(location.href)) {  // 来自 developer
        //     querys = 'source=' + source.developer + '&redirect=' + encodeURIComponent(window.Rokid.domain.skill + '/check_auth_info.do?redirect=' + location.href);
        // }else if(/account[a-zA-Z-_]*\.rokid\.com/gi.test(location.href)) { // 来自 account
        //     querys = 'source=' + source.account + '&redirect=' + location.href;
        // }else {
        //     querys = 'redirect=' + hrefWithoutToken();
        // }

        // location.href = href + '?' + querys;
    }

    if(err.response.status === 404 || err.response.status === 504) {
        errMsg = '访问服务器出错了.';
    }else if (err.response.status === 403) {
        errMsg = '请求访问权限不足.';
    }else if(err.response.status === 400 || err.response.status === 500) {    // 业务类型错误
        try {
            let message = Rokid.utils.toJSON(err.response.data.message);
            if(typeof(message) === 'string') {
                errMsg = message;
            }else {
                errMsg = '';
                message.map((item, index) => (errMsg += `${item.message}, `));
            }
        }catch(e) {
            console.log('处理请求异常错误: ', e);
        }
    }else {
        Webview.errorView();
    }

    Webview.toast(errMsg);

    return Promise.resolve(undefined);
})

export default axios;
