module.exports = {
    /**
     * 设置 cookie
     *
     * demo: MGTOOL.setCookie('_ccna', 2, {expire: 1, path: '/'});
     *
     * @param {string} name - cookie name
     * @param {string} value - cookie value
     * @param {object} options
     *          options.expire: 过期时间，单位为天
     *          options.path:   cookie 存放路径
     */
    setCookie: function(name, value, options) {
        options = options || {};
        if (value === null) {
            value = '';
            options.expires = -1;
        }
        var expires = '';
        if (options.expires && (typeof options.expires === 'number' || options.expires.toUTCString)) {
            var date;
            if (typeof options.expires === 'number') {
                date = new Date();
                date.setTime(date.getTime() + (options.expires * 86400000));
            } else {
                date = options.expires;
            }
            expires = '; expires=' + date.toUTCString();
        }
        var path = options.path ? '; path=' + (options.path) : '';
        var secure = options.secure ? '; secure' : '';
        var domain = '';
        if (options.domain) {
            domain = '; domain=' + (options.domain);
        } else {
            domain = document.domain.toString().split('.');
            domain = '; domain=.' + domain[1] + '.' + domain[2];
        }
        // console.log(name, value);
        // console.log([name, '=', encodeURIComponent(value), expires, path, domain, secure].join(''));
        document.cookie = [name, '=', encodeURIComponent(value), expires, path, domain, secure].join('');
    },

    /**
     * 获取 cookie 值, 如果 cookie 取不到，返回 '';
     * @param  {string} name - cookie name
     * @return {string} cookie value
     */
    getCookie: function(name) {
        var arr = document.cookie.match(new RegExp("(^| )" + name + "=([^;]*)(;|$)"));
        if (arr !== null) return decodeURIComponent(arr[2]);
        return '';
    },

    /**
     * 删除 cookie
     */
    removeCookie: function(name) {
        this.setCookie(name, null, {
            expires: -1
        });
    }
}
