import axios from 'axios'
import { Message } from 'iview'

axios.interceptors.request.use(config => {
    config.timeout = 20000
    return config
}, err => {
    Message.error('请求出错了！', 3)
    return Promise.resolve(err)
})

axios.interceptors.response.use(data => {
    return data
}, err => {
    if(!err.response) {
        Message.error('请求超时', 3)
        return Promise.resolve(undefined)
    }

    // 未登录 => 跳登录
    if(err.response.status === 401) {
        // 跳登录/注册来源跟踪
        let source = {
            developer: 'web_0021A47ECC1E4986ACC784524C2C4817',  // 来自开放平台
            account: 'web_43A1F5AC737B4BB584A0EB4EBAFEE578'     // 来自账户中心
        }

        let href = Rokid.domain.account + '/account.html#/login'
        let querys = ''

        if(/developer[a-zA-Z-_]*\.rokid\.com/gi.test(location.href)) {
            querys = 'source=' + source.developer + '&redirect=' + encodeURIComponent(window.Rokid.domain.skill + '/check_auth_info.do?redirect=' + location.href);
        }else if(/account[a-zA-Z-_]*\.rokid\.com/gi.test(location.href)) {
            querys = 'source=' + source.account + '&redirect=' + location.href
        }else {
            querys = 'redirect=' + location.href
        }

        location.href = href + '?' + querys
    }

    let errMsg = '请求出错了！'

    if(err.response.status === 404 || err.response.status === 504) {
        errMsg = '访问服务器出错了.'
    }else if (err.response.status === 403) {
        errMsg = '请求访问权限不足.'
    }else if(err.response.status === 400 || err.response.status === 500) {    // 业务类型错误
        try {
            let message = Rokid.utils.toJSON(err.response.data.message)
            if(typeof(message) === 'string') {
                errMsg = message
            }else {
                errMsg = ''
                message.map((item, index) => (errMsg += `${item.message}<br>`))
            }
        }catch(e) {
            console.log('处理请求异常错误: ', e)
        }
    }

    Message.error(errMsg, 3)

    return Promise.resolve(undefined);
})

export default axios
