/* eslint-disable no-unused-vars */
// import axios from 'axios';
import areaCode from 'assets/json/area-code.js';
import Vue from 'vue';
import { Message } from 'iview';
import { mapState } from 'vuex';

Vue.use(Message);

let forget = {
    data() {
        return {
            isSaving: false,
            areaCode,    // 区域码
            formData: {
                "confirmPassword": "",
                "mobile": "",
                "password": "",
                "token": "",
                regionCode: "+86"
            },

            errorMsg: {
                "mobile": "",
                "token": "",
                "password": "",
                "confirmPassword": ""
            },

            isCountOver: true,     // 倒计时结束
            timeField: 60
        }
    },
    computed: {
      ...mapState([
          'device_id',
          'phone'
      ])
    },

    methods: {

        // blur: 手机号格式校验
        checkMobile() {

            let result = true;
            let isMobileOk = /^[0-9]{6,15}$/.test(this.formData.mobile);

            if(this.formData.mobile === "") {
                this.errorMsg.mobile = "手机号码不能为空.";
                result = false;
            }else if(!isMobileOk){
                this.errorMsg.mobile = "手机号码格式不正确.";
                result = false;
            }else {
                this.errorMsg.mobile = "";
            }

            return result;
        },

        // 密码验证
        checkPassword() {
            let result = true;
            let passwordLen = this.formData.password.length;

            let isPasswordOk = /[a-zA-Z0-9]|@|_|-/.test(this.formData.password);
            let isLengthOk = ( passwordLen >= 6 && passwordLen <= 18);

            if(this.formData.password === "") {
                this.errorMsg.password = "密码不能为空.";
                result = false;
            }else if(!isPasswordOk || !isLengthOk) {
                this.errorMsg.password = "密码长度为 6-18位，支持大小写英文、数字、-、_、@.";
                result = false;
            }else if((this.formData.password !== this.formData.confirmPassword) && this.formData.password && this.formData.confirmPassword) {
                this.errorMsg.password = "前后密码不一致.";
                this.errorMsg.confirmPassword = "前后密码不一致."
                result = false;
            }else{
                this.errorMsg.password = "";
                this.errorMsg.confirmPassword = "";
            }

            return result;
        },

        // 表单数据验证
        formDataValidate() {

            let resultMobile = true;
            let resultToken = true;
            let resultPassword = true;
            let resultCheckPassword = true;

            // if(!this.formData.mobile) {
            //     this.errorMsg.mobile = "手机号不能为空.";
            //     resultMobile = false;
            // }else{
            //     this.errorMsg.mobile = "";
            // }

            if(!this.formData.token) {
                this.errorMsg.token= "请输入验证码.";
                resultToken = false;
            }else{
                this.errorMsg.token = "";
            }

            if(!this.formData.password) {
                this.errorMsg.password= "请输入密码.";
                resultPassword = false;
            }else{

                // 密码校验
                if(!this.checkPassword()) {
                    resultCheckPassword = false;
                }else if(this.formData.password !== this.formData.confirmPassword) {
                    this.errorMsg.password = "前后密码不一致.";
                    this.errorMsg.confirmPassword = "前后密码不一致."
                    resultCheckPassword = false;
                }else{
                    this.errorMsg.password = "";
                    this.errorMsg.confirmPassword = "";
                }

            }

            return resultMobile && resultToken && resultPassword && resultCheckPassword;
        },

        // 获取验证码
        getValidateCode() {

            let _this = this;

            let data = {
              "mobile": this.phone,
              "regionCode": this.formData.regionCode
            }
            
            _this.$jsonp(Rokid.domain.loginJSONP + '/rokid_service/getValidateCode', data)
                .then(json=>{                  
                  Rokid.utils.countDown.call(_this);
                  Message.success('校验码已发送.', 3);
                })
                .catch((err) => {
                  Message.error('发送验证码失败.', 3);
                });
        },

        // blur: 验证码验证
        checkValidateCode() {
            let result = true;
            let _this = this;
            console.log(this.phone);
            
            if(this.formData.token === '') {
                this.errorMsg.token = "请填写验证码.";
                result = false;
            }else{
                let data = {
                  "mobile": this.phone,
                  "token": this.formData.token
                }
                _this.$jsonp(Rokid.domain.loginJSONP + '/rokid_service/verifyCode', data)
                .then(json=>{
                  if (json.status === 201) {
                    _this.errorMsg.token = "";
                  } else {
                    _this.errorMsg.token = json.data.message;
                  }
                })
                .catch((err) => {
                  Message.error('发送验证码失败.', 3);
                });
            }

            return result;
        },

        pwdReset() {
            if(this.isSaving) return;

            if(!this.formDataValidate()) {
                return ;
            }
            console.log(this.formData, '=====this.formData====');
            this.isSaving = true;
            let _this = this;
            this.formData.mobile = this.phone;
            _this.$jsonp(Rokid.domain.loginJSONP + '/rokid_service/resetPwd', this.formData)
                .then(json=>{
                  _this.isSaving = false;
                  if (json.status === 201) {
                    
                    Message.success('密码修改成功.', 3);
                    setTimeout(function() {
                       _this.$router.replace('/login');
                    }, 2200);
                  } else {
                    Message.error(json.data.message, 3);
                    // _this.errorMsg.token = json.data.message;
                  }
                })
                .catch((err) => {
                  Message.error('密码修改失败.', 3);
                });
        }
    },

    filters: {
        areaCodeCollect(countryObj) {
            let key = Object.keys(countryObj)[0];

            return '(+' + key + ') ' + countryObj[key];
        }
    }
}

export default forget
