// 检查 Node 和 npm 版本
require('./bundle/check-versions')()
require('colors')

const ora = require('ora')          // loading 插件
const rm = require('rimraf')       // node 的深度删除模块(like `rm -rf`)
const path = require('path')
const webpack = require('webpack')
const archiver = require('archiver')
const fs = require('fs')

let utils = require('./bundle/utils')
let config = require('./bundle/config')
let webpackConfig = require('./bundle/webpack.prod.conf.js')
let spinner = ora()          // 使用 ora 打印出 loading + log   'building for production...\n'

module.exports = function (pagename, platform) {

    return new Promise((resolve, reject) => {

        spinner.start()  // 开始 loading 动画

        let assetsPath = path.join(config.build.assetsRoot, config.build.appDir + '/' + pagename + '/' + platform)

        rm(assetsPath, err => {
            if (err) return reject(err)

            let packConfig = webpackConfig.custom(pagename, platform)
            webpack(packConfig, function (err, stats) {

                // 编译成功的回调函数
                spinner.stop()
                if (err) return reject(err)

                process.stdout.write(stats.toString({
                    colors: true,
                    modules: false,
                    children: false,
                    chunks: false,
                    chunkModules: false
                }) + '\n\n')

                var output = fs.createWriteStream(assetsPath + '/' + pagename + '-' + platform + '.zip');
                //创建一最终打包文件的输出流
                // var output = fs.createWriteStream(zipPath)
                // //生成archiver对象，打包类型为zip
                var zipArchiver = archiver('zip')
                // //将打包对象与输出流关联
                zipArchiver.pipe(output)
                zipArchiver.append(fs.createReadStream(assetsPath + '/index.html'), {'name': 'index.html'})
                zipArchiver.directory(assetsPath + '/static', 'static');
                // //打包
                zipArchiver.finalize();
                console.log('Build complete.\n'.green)
                resolve()
            })

        })
    })
}
