const path = require('path')
const config = require('./config')
const ExtractTextPlugin = require('extract-text-webpack-plugin')

exports.assetsPath = function (_path) {

    // config.build.assetsSubDirectory => 'static'
    // config.dev.assetsSubDirectory => 'static'
    var assetsSubDirectory = process.env.NODE_ENV === 'production'
    ? config.build.assetsSubDirectory
    : config.dev.assetsSubDirectory
    return path.posix.join(assetsSubDirectory, _path)
}

exports.cssLoaders = function (options) {
  options = options || {}

  var cssLoader = {
    loader: 'css-loader',
    options: {
      minimize: process.env.NODE_ENV === 'production',
      sourceMap: options.sourceMap
    }
  }
  var px2remLoader = {
    loader: 'px2rem-loader',
    options: {
      remUnit: 75
    }
  }

  // generate loader string to be used with extract text plugin
  function generateLoaders (loader, loaderOptions) {
    var loaders = [cssLoader, px2remLoader]
    if (loader) {
      loaders.push({
        loader: loader + '-loader',
        options: Object.assign({}, loaderOptions, {
          sourceMap: options.sourceMap
        })
      })
    }

    // Extract CSS when that option is specified
    // (which is the case during production build)
    if (options.extract) {
      return ExtractTextPlugin.extract({
        use: loaders,
        publicPath: '../../',
        fallback: 'vue-style-loader'
      })
    } else {
      return ['vue-style-loader'].concat(loaders)
    }
  }

  // http://vuejs.github.io/vue-loader/en/configurations/extract-css.html
  return {
    css: generateLoaders(),
    postcss: generateLoaders(),
    less: generateLoaders('less'),
    sass: generateLoaders('sass', { indentedSyntax: true }),
    scss: generateLoaders('sass'),
    stylus: generateLoaders('stylus'),
    styl: generateLoaders('stylus')
  }
}

// Generate loaders for standalone style files (outside of .vue)
exports.styleLoaders = function (options) {
  var output = []
  var loaders = exports.cssLoaders(options)
  for (var extension in loaders) {
    var loader = loaders[extension]
    output.push({
      test: new RegExp('\\.' + extension + '$'),
      use: loader
    })
  }
  return output
}

/**
 * path：/Users/hizhou/workspace/lego-local-project/src/h5_go_sales_seckill/index.html
 * path.basename: index.html
 * path.extname: .html (后缀名)
 * path.dirname: /Users/hizhou/workspace/lego-local-project/src/h5_go_sales_seckill （目录）
 */
exports.getEntry = function (globPath) {
    //这里的glob是nodejs的glob模块，是用来读取webpack入口目录文件的
    var glob = require('glob')
    var entries = {},
      basename, tmp, pathname

    glob.sync(globPath).forEach(function (entry) {
        let pagePath = path.parse(entry)   // { root: '...', dir: '', base: '', ext: '', name: '' }
        let name = pagePath.name
        let platform = ''

        entry.replace(/(pc|h5)/i, function($1){
            platform = $1
        })

        let pageName = name + '-' + platform

        entries[pageName] = entry

    });

    return entries
}
