require('colors');

const path = require('path')
const utils = require('./utils')
const webpack = require('webpack')
const ExtractTextPlugin = require("extract-text-webpack-plugin")
const HtmlReplaceWebpackPlugin = require('html-replace-webpack-plugin')
const ARGV = require('minimist')(process.argv.slice(2))._
const config = require('./config')

let isProduction = process.env.NODE_ENV !== 'development'
let entries = {}

ARGV.forEach((argv, index) => {     // argv => store-pc
    if(argv) {
        let module = argv.split('-')
        entries[argv] = `./apps/modules/${module[0]}/${module[1]}/index.js`
    }
})

// 线上js
let js = {
    'vue-pc': 'https://p.rokidcdn.com/web/lib/vue/vue-complex-pc.2.5.13.min.js',
    'vue-h5': 'https://p.rokidcdn.com/web/lib/vue/vue-complex-h5.2.5.13.min.js'
}
// 线下js
if(!isProduction) {
    js = {
        'vue-pc': 'https://p.rokidcdn.com/web/lib/vue/vue-2.5.13.js',
        'vue-h5': 'https://p.rokidcdn.com/web/lib/vue/vue-2.5.13.js',
        'vue-router': 'https://p.rokidcdn.com/web/lib/vue/vue-router-3.0.1.js'
    }
}
let resource = { js }
let tpl = {
    js: '<script type="text/javascript" src="%s"></script>'
}
console.log('entries: ', entries)
module.exports = {

    entry: entries,

    resolve: {

        // 自动补全的扩展名
        extensions: ['.js', '.vue', '.json', '.less'],

        alias: {
            '@': path.resolve(__dirname, '../../apps'),
            'assets': path.resolve(__dirname, '../../apps/assets'),
            'components': path.resolve(__dirname, '../../apps/components')
        }

    },

    plugins: [
        new HtmlReplaceWebpackPlugin([
            {
              pattern: /(<!--\s*|@@)(css|js|img):([\w-\/]+)(\s*-->)?/g,
              replacement: function(match, $1, type, file, $4, index, input) {
                  var url = resource[type][file]
                  if(url) {
                      return $4 == undefined ? url : tpl[type].replace('%s', url)
                  }else {
                      return ''
                  }
              }
            }
        ])
    ],

    module: {
        rules: [
            {
                test: /\.(js|vue)$/,
                loader: 'eslint-loader',
                enforce: "pre",
                include: [path.resolve(__dirname, '../../apps')],
                options: {
                    formatter: require('eslint-friendly-formatter')
                }
            },

            {
                test: /\.vue$/,
                loader: 'vue-loader',
                options: {
                    loaders: utils.cssLoaders({
                        sourceMap: isProduction
                          ? config.build.productionSourceMap
                          : config.dev.cssSourceMap,
                        extract: isProduction
                    })
                }
            },

            // {
            //     test: /\.vue$/,
            //     use: {
            //         loader: 'vue-loader',
            //         options: {
            //             extractCSS: true,
            //             loaders: ExtractTextPlugin.extract({
            //                 use: [
            //                     'vue-style-loader',
            //                     'css-loader?-minimize',
            //                     'postcss-loader',
            //                     'less-loader'
            //                 ],
            //                 publicPath: isProduction ? '../../': '/',
            //             })
            //         }
            //     }
            // },

            {
                test: /\.js$/,
                loader: 'babel-loader',
                include: [path.resolve(__dirname, '../../apps')]
            },

            {
                test: /\.(png|jpe?g|gif|svg)(\?.*)?$/,
                loader: 'url-loader',
                query: {
                    limit: 2048,
                    name: utils.assetsPath('img/[name].[hash:7].[ext]')
                }
            },

            {
                test: /\.(woff2?|eot|ttf|otf)(\?.*)?$/,
                loader: 'url-loader',
                query: {
                    limit: 2048,
                    name: utils.assetsPath('fonts/[name].[hash:7].[ext]')
                }
            }

        ]
    }
}
