const path = require('path')
const webpack = require('webpack')
const merge = require('webpack-merge')
const HtmlWebpackPlugin = require('html-webpack-plugin')
const FriendlyErrorsPlugin = require('friendly-errors-webpack-plugin')

const ExtractTextPlugin = require("extract-text-webpack-plugin")
const utils = require('./utils')

const TEXT_COMMAND_WRONG = [
    `--- 执行命令错误! \n`,
    `--- 正确命令: \n`,
    `--- 运行一个项目：npm run dev app1 \n`,
    `--- 同时运行两个项目：npm run dev app1 app2 \n`,
    `--- 同时运行n个项目：npm run dev app1 app2 ... appn`
].join('')

/*
 *  入口配置文件校验
 */
let baseWebpackConfig = require('./webpack.base.conf') // 引入 webpack.base.conf 配置文件
if(Object.keys(baseWebpackConfig.entry).length <= 0) {
    console.error(TEXT_COMMAND_WRONG.red);
    process.exit(0);
}

/*
 *  add hot-reload related code to entry chunks
 *  baseWebpackConfig.entry => {
 *      account: [ './build/dev-client', './src/module/account/account.js' ],
 *      skill: ['./build/dev-client', './src/module/skill/skill.js']
 *  }
*/
Object.keys(baseWebpackConfig.entry).forEach(function (name) {
    baseWebpackConfig.entry[name] = ['./build/bundle/dev-client'].concat(baseWebpackConfig.entry[name])
});

/*
 * 根据entry配置，生成多个html实例
 */
function createHtmlPlugins() {

    let pages = Object.keys(baseWebpackConfig.entry)
    let htmlPlugins = []

    pages.forEach((pathname, index) => {

        let module = pathname.split('-')
        let name = module[0]
        let platform = module[1]

        let conf = {
            chunks: [ pathname ],
            filename: pathname + '.html',
            template: './apps/modules/' + name + '/' + platform + '/index.html', // 模板路径
            inject: true                  // js插入位置
        }

        htmlPlugins.push(new HtmlWebpackPlugin(conf))

    })

    return htmlPlugins

}

// 合并 webpack.dev.conf.js 的配置和 webpack.base.conf.js 的配置
module.exports = merge(baseWebpackConfig, {

    output: {
        //   编译输出的根路径 /dist
        path: path.resolve(__dirname, '../../dist'),
        filename: '[name].js',
        publicPath: '/'
    },

    devtool: 'source-map',      // cheap-module-eval-source-map is faster for development

    plugins: [
        new ExtractTextPlugin({
            filename: '[name].[contenthash:6].css'
        }),
        new webpack.HotModuleReplacementPlugin(),
        new webpack.NoEmitOnErrorsPlugin(),
        new FriendlyErrorsPlugin()
    ].concat(createHtmlPlugins())
})
