const path = require('path')
const webpack = require('webpack')
const merge = require('webpack-merge')
const HtmlWebpackPlugin = require('html-webpack-plugin')                    // 一个可以插入 html 并且创建新的 .html 文件的插件
const ExtractTextPlugin = require('extract-text-webpack-plugin')            // 文件提取
const OptimizeCSSPlugin = require('optimize-css-assets-webpack-plugin')

let utils = require('./utils')
let config = require('./config')
let baseWebpackConfig = require('./webpack.base.conf')

module.exports = {

    custom: function (pagename, platform) {

        var webpackConfig = merge(baseWebpackConfig, {

            module: {
                rules: utils.styleLoaders({
                    sourceMap: config.build.productionSourceMap,
                    extract: true
                })
            },

            devtool: false,

            output: {
                // 编译输出目录 dist/app/pagename
                path: path.resolve(config.build.assetsRoot, `${config.build.appDir}/${pagename}/${platform}`),
                filename: utils.assetsPath('js/[name].[chunkhash:6].js'),
                publicPath: './',
                chunkFilename: utils.assetsPath('js/[id].[chunkhash:6].js')
            },

            plugins: [

                // 压缩 js (同样可以压缩 css)
                new webpack.optimize.UglifyJsPlugin({
                    compress: {
                        warnings: false
                    },
                    sourceMap: true
                }),

                // extract css into its own file
                // 将 css 文件分离出来
                // extract css into its own file
                new ExtractTextPlugin({
                    filename: utils.assetsPath('css/[name].[contenthash:6].css')
                }),

                // Compress extracted CSS. We are using this plugin so that possible
                // duplicated CSS from different components can be deduped.
                new OptimizeCSSPlugin(),

                // 没有指定输出文件名的文件输出的静态文件名
                // split vendor js into its own file
                new webpack.optimize.CommonsChunkPlugin({
                    name: 'vendor',
                    minChunks: function (module, count) {
                        // any required modules inside node_modules are extracted to vendor
                        return (
                            module.resource &&
                            /\.js$/.test(module.resource) &&
                            module.resource.indexOf(
                                path.join(__dirname, '../../node_modules')
                            ) === 0
                        )
                    }
                }),

                // 没有指定输出文件名的文件输出的静态文件名
                new webpack.optimize.CommonsChunkPlugin({
                    name: 'manifest',
                    chunks: ['vendor']
                }),

                new HtmlWebpackPlugin({
                    filename: path.resolve(__dirname, `../../dist/${config.build.appDir}/${pagename}/${platform}/index.html`),
                    template: `./apps/modules/${pagename}/${platform}/index.html`,
                    inject: true,
                    minify: {       // 压缩的方式
                        removeComments: true,
                        collapseWhitespace: true,
                        removeAttributeQuotes: true
                    },
                    // necessary to consistently work with multiple chunks via CommonsChunkPlugin
                    chunksSortMode: 'dependency'
                })
            ]
        })

        webpackConfig.entry = {};
        webpackConfig.entry[pagename] = ['./apps/modules/' + pagename + '/' + platform + '/index.js'];

        return webpackConfig;
    }
}
