require('./bundle/check-versions')()

const path = require('path')
const fs = require('fs')
const http = require('http')
const https = require('https')
const proxyMiddleware = require('http-proxy-middleware')
const webpack = require('webpack')
const express = require('express')
const app = express()
const opn = require('opn')
let config = require('./bundle/config')
let webpackConfig = require('./bundle/webpack.dev.conf')
let port = process.env.PORT || config.dev.port
let proxyTable = config.dev.proxyTable
let compiler = webpack(webpackConfig)           // 使用 webpack 编译
const ARGV = require('minimist')(process.argv.slice(2))._

// force page reload when html-webpack-plugin template changes
compiler.plugin('compilation', function (compilation) {
    compilation.plugin('html-webpack-plugin-after-emit', function (data, cb) {
        hotMiddleware.publish({ action: 'reload' })
        cb()
    })
})

Object.keys(proxyTable).forEach(function (context) {

    var options = proxyTable[context];

    if (typeof options === 'string') {
        options = {
            target: options,
            changeOrigin: true
        }
    }

    app.use(context, proxyMiddleware(options));
})

// handle fallback for HTML5 history API
app.use(require('connect-history-api-fallback')())

// webpack-dev-middleware: webpack 包装中间件，编译后的文件暂存到内存中
let devMiddleware = require('webpack-dev-middleware')(compiler, {
    publicPath: webpackConfig.output.publicPath,      // /
    quiet: true
})

app.use(devMiddleware)


// 启动 webpack-hot-middleware(Hot-reload)
let hotMiddleware = require('webpack-hot-middleware')(compiler, {
    log: () => {}
})

app.use(hotMiddleware)

// staticPath => /static
let staticPath = path.posix.join(config.dev.assetsPublicPath, config.dev.assetsSubDirectory)
app.use(staticPath, express.static('./static'))

http.createServer(app).listen(port, function(err) {
    if (err) {
        console.log(err)
        return
    }
    console.log('HTTP Server is running on: http://localhost:%s'.green.underline, port);
    opn('http://localhost:'+ port + '/' + ARGV[0] + '.html')
});
